@@ -386,12 +386,14 @@ sub compiled_writer {
 }
 
 # This method combines the output and format settings into a writer.
+# It also ensures the output is using autoflush
 sub _build_writer_cache {
 	my $self= shift;
 	my $code= "sub {  \n" . $self->_build_writer_code . "\n}";
 	my $err;
 	my $writer= $self->_build_writer_eval_in_clean_scope( $code, \$err )
 		or croak "Compilation of log writer failed: $err\nSource code is: $code";
+	$self->_enable_autoflush($self->output);
 	return $writer;
 }
 
@@ -438,6 +440,25 @@ sub _build_writer_code {
 	return $code;
 }
 
+sub _enable_autoflush {
+	my ($self, $thing)= @_;
+	# This module tries to be very backward-compatible, and not force people to use IO::Handle
+	# if they didn't intend to...
+	if (ref $thing eq 'GLOB') {
+		my $prev= select($thing);
+		$|= 1;
+		select($prev);
+		1;
+	}
+	elsif (ref($thing)->can('autoflush')) {
+		$thing->autoflush(1);
+		1;
+	}
+	else {
+		0;
+	}
+}
+
 # "Cached Adapters" is conceptually a field of the config object, but then
 # it shows a giant mess if/when you Dump() the object, so I'm using this trick
 # to keep the list attached to the package instead of the object.
@@ -484,7 +505,7 @@ Log::Any::Adapter::Daemontools::Config - Dynamic configuration settings used by
 
 =head1 VERSION
 
-version 0.100002
+version 0.100003
 
 =head1 SYNOPSIS
 
@@ -849,7 +870,8 @@ Basically:
 =head2 compiled_writer
 
 This returns the L</writer> attribute if it is defined, or the compiled
-result of L</output> and L</format> otherwise.
+result of L</output> and L</format> otherwise.  If it builds a writer from
+L</output>, it will also enable autoflush on that file handle.
 
 =head1 AUTHOR
 
